@@ -13,7 +13,7 @@ class Provider(PersonProvider):
         '{{first_name_female}} {{last_name}}',
         '{{prefix_female}} {{first_name_female}} {{last_name}}',
         '{{first_name_female}} {{last_name}} {{suffix}}',
-        '{{prefix_female}} {{first_name_female}} {{last_name}} {{suffix}}'
+        '{{prefix_female}} {{first_name_female}} {{last_name}} {{suffix}}',
     )
 
     formats_male = (
@@ -24,7 +24,7 @@ class Provider(PersonProvider):
         '{{first_name_male}} {{last_name}}',
         '{{prefix_male}} {{first_name_male}} {{last_name}}',
         '{{first_name_male}} {{last_name}} {{suffix}}',
-        '{{prefix_male}} {{first_name_male}} {{last_name}} {{suffix}}'
+        '{{prefix_male}} {{first_name_male}} {{last_name}} {{suffix}}',
     )
 
     formats = formats_female + formats_male
@@ -41,11 +41,11 @@ class Provider(PersonProvider):
         'آیدا', 'الناز', 'محدثه', 'یاسمین',
         # http://www.sabteahval.ir/Upload/Modules/Contents/asset100/name/d1393.htm
         'فاطمه', 'ستايش', 'زهرا', 'مائده', 'نازنين', 'مبينا', 'يسنا', 'عسل',
-        'زينب', 'آيناز', 'ريحانه', 'هليا', 'فاطمه', 'سوگند', 'باران', 'سارا', 'رها','محدثه',
+        'زينب', 'آيناز', 'ريحانه', 'هليا', 'فاطمه', 'سوگند', 'باران', 'سارا', 'رها', 'محدثه',
         'ثنا', 'الينا', 'کوثر', 'آتنا', 'مريم', 'فاطميا''سارينا', 'ياسمين', 'اسرا',
         'حسنا', 'رقيه', 'اسما', 'هستي', 'مهديس', 'محيا', 'هانيه', 'آيلين', 'حنانه',
         'مهسا', 'پرنيا', 'نرگس', 'آيدا', 'معصومه', 'کيانا', 'حلما', 'مليکا', 'آوا',
-        'نازنين', 'النا', 'الناز', 'نيايش','بهار'
+        'نازنين', 'النا', 'الناز', 'نيايش', 'بهار',
     )
 
     first_names_male = (
@@ -62,8 +62,8 @@ class Provider(PersonProvider):
         # http://www.sabteahval.ir/Upload/Modules/Contents/asset100/name/p1393.htm
         'اميرعلي', 'ايليا', 'محمد', 'محمدپارسا', 'محمد', 'پرهام', 'ابوالفضل',
         'سبحان', 'اميرحسين', 'آرتين', 'علي', 'آرمين', 'حسين', 'عرفان', 'اميرمحمد',
-         'آريا', 'اميرعباس', 'محمدياسين', 'محمدمهدي', 'متين', 'محمدرضا', 'دانيال',
-         'مهدي', 'ساميار', 'محمدحسين', 'احسان', 'اميررضا', 'آرين', 'عليرضا', 'سينا',
+        'آريا', 'اميرعباس', 'محمدياسين', 'محمدمهدي', 'متين', 'محمدرضا', 'دانيال',
+        'مهدي', 'ساميار', 'محمدحسين', 'احسان', 'اميررضا', 'آرين', 'عليرضا', 'سينا',
         'محمدامين', 'آراد', 'علي', 'سجاد', 'طاها', 'حسام', 'رضا', 'يوسف', 'ماهان', 'آرش',
         'مبين', 'ياسين', 'علي', 'اميرمهدي', 'عباس', 'پارسا', 'محمدعلي', 'کيان',
         'محمدجواد', 'بنيامين',
